
#' A128 example matrix
#' @name A128
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"A128"


#' A313 example matrix
#' @name A313
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"A313"


#' ageM1 example vector
#' @name ageM1
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"ageM1"


#' ageM4 example vector
#' @name ageM4
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"ageM4"


#' ageM18 example vector
#' @name ageM18
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"ageM18"


#' ageM32 example vector
#' @name ageM32
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"ageM32"


#' ageM128 example vector
#' @name ageM128
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"ageM128"


#' ageM313 example vector
#' @name ageM313
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"ageM313"


#' ageM201 example vector
#' @name ageM201
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"ageM201"


#' ageSD1 example vector
#' @name ageSD1
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"ageSD1"


#' ageSD4 example vector
#' @name ageSD4
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"ageSD4"


#' ageSD18 example vector
#' @name ageSD18
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"ageSD18"


#' ageSD32 example vector
#' @name ageSD32
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"ageSD32"


#' ageSD128 example vector
#' @name ageSD128
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"ageSD128"


#' ageSD313 example vector
#' @name ageSD313
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"ageSD313"


#' ageSD201 example vector
#' @name ageSD201
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"ageSD201"


#' alphas128 example vector
#' @name alphas128
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"alphas128"


#' alphas313 example vector
#' @name alphas313
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"alphas313"


#' burnout1 example vector
#' @name burnout1
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"burnout1"


#' burnout4 example vector
#' @name burnout4
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"burnout4"


#' burnout18 example vector
#' @name burnout18
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"burnout18"


#' burnout32 example vector
#' @name burnout32
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"burnout32"


#' burnout128 example vector
#' @name burnout128
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"burnout128"


#' burnout313 example vector
#' @name burnout313
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"burnout313"


#' burnout201 example vector
#' @name burnout201
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"burnout201"


#' combineVariables128 example vector
#' @name combineVariables128
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"combineVariables128"


#' combineVariablesNames128 example vector
#' @name combineVariablesNames128
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"combineVariablesNames128"


#' ctmaBiG-object reproducing results of Guthier et al. (2020)
#' @name CoTiMABiG_D_BO
#' @docType data
#' @author C. Guthier, C. Dormann & J. Cortina \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"CoTiMABiG_D_BO"


#' ctmaFit-object with a 'full' CoTiMA of 6 studies
#' @name CoTiMAFullFit_6
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"CoTiMAFullFit_6"


#' ctmaFit-object with a 'full' CoTiMA of 6 studies
#' @name CoTiMAFullFit_6_new
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"CoTiMAFullFit_6_new"


#' ctmaFit-object with a 'full' CoTiMA of 3 studies
#' @name CoTiMAFullFit_3
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"CoTiMAFullFit_3"


#' 1st fitted ctmaFit-object in a series of 2 to test equality of 2 cross effects
#' @name CoTiMAFullInv23Fit_6
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"CoTiMAFullInv23Fit_6"


#' 2nd fitted ctmaFit-object in a series of 2 to test equality of 2 cross effects
#' @name CoTiMAFullInvEq23Fit_6
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"CoTiMAFullInvEq23Fit_6"


#' ctmaInit-object with a 'full' CoTiMA of 6 studies using NUTS sampler
#' @name CoTiMAInitFit_6_NUTS
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"CoTiMAInitFit_6_NUTS"


#' ctmaInit-object with 6 primary studies
#' @name CoTiMAInitFit_6
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"CoTiMAInitFit_6"


#' ctmaInit-object with 6 primary studies
#' @name CoTiMAInitFit_6_new
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"CoTiMAInitFit_6_new"


#' ctmaInit-object created by Guthier et al. (2020) with 48 primary studies
#' @name CoTiMAInitFit_D_BO
#' @docType data
#' @author  C. Guthier, C. Dormann & J. Cortina \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"CoTiMAInitFit_D_BO"


#' ctmaInit-object with of 3 primary studies
#' @name CoTiMAInitFit_3
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"CoTiMAInitFit_3"


#' ctmaFit-object with a categorical moderator of the full drift matrix
#' @name CoTiMAMod1onFullFit_6
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"CoTiMAMod1onFullFit_6"


#' ctmaFit-object with a categorical moderator of the full drift matrix
#' @name CoTiMAMod1onFullFit_6_cats12
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"CoTiMAMod1onFullFit_6_cats12"


#' ctmaFit-object with a continuous moderator of 2 cross effects
#' @name CoTiMAMod2on23Fit_6
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"CoTiMAMod2on23Fit_6"


#' ctmaFit-object with with only one cross effect and this one set equal across primary studies
#' @name CoTiMAPart134Inv3Fit_6
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"CoTiMAPart134Inv3Fit_6"


#' ctmaPower-object reproducing results of Guthier et al. (2020)
#' @name CoTiMAPower_D_BO
#' @docType data
#' @author C. Guthier, C. Dormann & J. Cortina  \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"CoTiMAPower_D_BO"


#' ctmaPrep-object created with 3 primary studies
#' @name CoTiMAstudyList_3
#' @docType data
#' @author C. Guthier, C. Dormann & J. Cortina  \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"CoTiMAstudyList_3"


#' ctmaPrep-object created with 6 primary studies
#' @name CoTiMAstudyList_6
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"CoTiMAstudyList_6"


#' ctmaPrep-object created with 6 primary studies
#' @name CoTiMAstudyList_6_new
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"CoTiMAstudyList_6_new"


#' object created to store standard parameters passed forward to ctStanFit
#' @name CoTiMAStanctArgs
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"CoTiMAStanctArgs"


#' country1 example vector
#' @name country1
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"country1"


#' country4 example vector
#' @name country4
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"country4"


#' country18 example vector
#' @name country18
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"country18"


#' country32 example vector
#' @name country32
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"country32"


#' country128 example vector
#' @name country128
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"country128"


#' country313 example vector
#' @name country313
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"country313"


#' country201 example vector
#' @name country201
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"country201"


#' delta_t1 example vector
#' @name delta_t1
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"delta_t1"


#' delta_t4 example vector
#' @name delta_t4
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"delta_t4"


#' delta_t18 example vector
#' @name delta_t18
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"delta_t18"


#' delta_t32 example vector
#' @name delta_t32
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"delta_t32"


#' delta_t128 example vector
#' @name delta_t128
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"delta_t128"

#' delta_t228 example vector
#' @name delta_t228
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"delta_t228"


#' delta_t313 example vector
#' @name delta_t313
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"delta_t313"


#' delta_t201 example vector
#' @name delta_t201
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"delta_t201"


#' demands1 example vector
#' @name demands1
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"demands1"


#' demands4 example vector
#' @name demands4
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"demands4"


#' demands18 example vector
#' @name demands18
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"demands18"


#' demands32 example vector
#' @name demands32
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"demands32"


#' demands128 example vector
#' @name demands128
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"demands128"


#' demands313 example vector
#' @name demands313
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"demands313"


#' demands201 example vector
#' @name demands201
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"demands201"


#' dl_link example path
#' @name dl_link
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"dl_link"


#' empcov1 example matrix
#' @name empcov1
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"empcov1"


#' empcov4 example matrix
#' @name empcov4
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"empcov4"


#' empcov18 example matrix
#' @name empcov18
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"empcov18"


#' empcov32 example matrix
#' @name empcov32
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"empcov32"


#' empcov128 example matrix
#' @name empcov128
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"empcov128"


#' empcov313 example matrix
#' @name empcov313
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"empcov313"


#' empcov201 example matrix
#' @name empcov201
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"empcov201"


#' malePercent1 example vector
#' @name malePercent1
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"malePercent1"


#' malePercent4 example vector
#' @name malePercent4
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"malePercent4"


#' malePercent18 example vector
#' @name malePercent18
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"malePercent18"


#' malePercent32 example vector
#' @name malePercent32
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"malePercent32"


#' malePercent128 example vector
#' @name malePercent128
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"malePercent128"


#' malePercent313 example vector
#' @name malePercent313
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"malePercent313"


#' malePercent201 example vector
#' @name malePercent201
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"malePercent201"


#' moderator1 example vector
#' @name moderator1
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"moderator1"


#' moderator4 example vector
#' @name moderator4
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"moderator4"


#' moderator18 example vector
#' @name moderator18
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"moderator18"


#' moderator32 example vector
#' @name moderator32
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"moderator32"


#' moderator128 example vector
#' @name moderator128
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"moderator128"


#' moderator313 example vector
#' @name moderator313
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"moderator313"


#' moderator201 example vector
#' @name moderator201
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"moderator201"


#' moderatorLabels example vector
#' @name moderatorLabels
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"moderatorLabels"


#' moderatorValues example vector
#' @name moderatorValues
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"moderatorValues"


#' occupation1 example vector
#' @name occupation1
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"occupation1"


#' occupation4 example vector
#' @name occupation4
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"occupation4"


#' occupation18 example vector
#' @name occupation18
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"occupation18"


#' occupation32 example vector
#' @name occupation32
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"occupation32"


#' occupation128 example vector
#' @name occupation128
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"occupation128"


#' occupation313 example vector
#' @name occupation313
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"occupation313"


#' occupation201 example vector
#' @name occupation201
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"occupation201"


#' pairwiseN128 example vector
#' @name pairwiseN128
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"pairwiseN128"


#' pubList_8 example list
#' @name pubList_8
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"pubList_8"


#' rawData228 example list
#' @name rawData228
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"rawData228"


#' recodeVariables128 example vector
#' @name recodeVariables128
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"recodeVariables128"


#' results128 example list
#' @name results128
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"results128"


#' sampleSize1 example vector
#' @name sampleSize1
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"sampleSize1"


#' sampleSize4 example vector
#' @name sampleSize4
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"sampleSize4"


#' sampleSize18 example vector
#' @name sampleSize18
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"sampleSize18"


#' sampleSize32 example vector
#' @name sampleSize32
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"sampleSize32"


#' sampleSize128 example vector
#' @name sampleSize128
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"sampleSize128"


#' sampleSize313 example vector
#' @name sampleSize313
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"sampleSize313"


#' sampleSize201 example vector
#' @name sampleSize201
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"sampleSize201"


#' source1 example vector
#' @name source1
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"source1"


#' source4 example vector
#' @name source4
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"source4"

#' source18 example vector
#' @name source18
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"source18"

#' source128 example vector
#' @name source128
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"source128"


#' source313 example vector
#' @name source313
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"source313"


#' source201 example vector
#' @name source201
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"source201"


#' targetVariables1 example vector
#' @name targetVariables1
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"targetVariables1"


#' targetVariables4 example vector
#' @name targetVariables4
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"targetVariables4"


#' targetVariables128 example vector
#' @name targetVariables128
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"targetVariables128"


#' targetVariables313 example vector
#' @name targetVariables313
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"targetVariables313"


#' variableNames128 example vector
#' @name variableNames128
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"variableNames128"

#' variableNames18 example vector
#' @name variableNames18
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"variableNames18"

#' variableNames32 example vector
#' @name variableNames32
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"variableNames32"

#' variableNames201 example vector
#' @name variableNames201
#' @docType data
#' @author C. Dormann & M. Homburg \email{CoTiMA@@uni-mainz.org}
#' @keywords data
"variableNames201"

